export declare type Maybe<T> = T | null;
export declare type InputMaybe<T> = Maybe<T>;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    Any: any;
    Int64: any;
    Timestamp: any;
};
export declare type BackendErrorObjectInput = {
    event: Scalars['String'];
    payload?: InputMaybe<Scalars['String']>;
    request_id: Scalars['String'];
    session_secure_id: Scalars['String'];
    source: Scalars['String'];
    stackTrace: Scalars['String'];
    timestamp: Scalars['Timestamp'];
    type: Scalars['String'];
    url: Scalars['String'];
};
export declare type ErrorObjectInput = {
    columnNumber: Scalars['Int'];
    event: Scalars['String'];
    lineNumber: Scalars['Int'];
    payload?: InputMaybe<Scalars['String']>;
    source: Scalars['String'];
    stackTrace: Array<InputMaybe<StackFrameInput>>;
    timestamp: Scalars['Timestamp'];
    type: Scalars['String'];
    url: Scalars['String'];
};
export declare type MetricInput = {
    category?: InputMaybe<Scalars['String']>;
    group?: InputMaybe<Scalars['String']>;
    name: Scalars['String'];
    session_secure_id: Scalars['String'];
    timestamp: Scalars['Timestamp'];
    type?: InputMaybe<Scalars['Any']>;
    url?: InputMaybe<Scalars['String']>;
    value: Scalars['Float'];
};
export declare type Mutation = {
    __typename?: 'Mutation';
    addSessionFeedback: Scalars['ID'];
    addSessionProperties?: Maybe<Scalars['ID']>;
    addTrackProperties?: Maybe<Scalars['ID']>;
    identifySession?: Maybe<Scalars['ID']>;
    initializeSession?: Maybe<Session>;
    markBackendSetup: Scalars['ID'];
    pushBackendPayload?: Maybe<Scalars['Any']>;
    pushMetrics: Scalars['ID'];
    pushPayload: Scalars['Int'];
};
export declare type MutationAddSessionFeedbackArgs = {
    session_id: Scalars['ID'];
    timestamp: Scalars['Timestamp'];
    user_email?: InputMaybe<Scalars['String']>;
    user_name?: InputMaybe<Scalars['String']>;
    verbatim: Scalars['String'];
};
export declare type MutationAddSessionPropertiesArgs = {
    properties_object?: InputMaybe<Scalars['Any']>;
    session_id: Scalars['ID'];
};
export declare type MutationAddTrackPropertiesArgs = {
    properties_object?: InputMaybe<Scalars['Any']>;
    session_id: Scalars['ID'];
};
export declare type MutationIdentifySessionArgs = {
    session_id: Scalars['ID'];
    user_identifier: Scalars['String'];
    user_object?: InputMaybe<Scalars['Any']>;
};
export declare type MutationInitializeSessionArgs = {
    appVersion?: InputMaybe<Scalars['String']>;
    clientConfig: Scalars['String'];
    clientVersion: Scalars['String'];
    client_id?: InputMaybe<Scalars['String']>;
    enable_recording_network_contents: Scalars['Boolean'];
    enable_strict_privacy: Scalars['Boolean'];
    environment: Scalars['String'];
    fingerprint: Scalars['String'];
    firstloadVersion: Scalars['String'];
    organization_verbose_id: Scalars['String'];
    session_secure_id?: InputMaybe<Scalars['String']>;
};
export declare type MutationMarkBackendSetupArgs = {
    session_secure_id: Scalars['String'];
};
export declare type MutationPushBackendPayloadArgs = {
    errors: Array<InputMaybe<BackendErrorObjectInput>>;
};
export declare type MutationPushMetricsArgs = {
    metrics: Array<InputMaybe<MetricInput>>;
};
export declare type MutationPushPayloadArgs = {
    errors: Array<InputMaybe<ErrorObjectInput>>;
    events: ReplayEventsInput;
    has_session_unloaded?: InputMaybe<Scalars['Boolean']>;
    highlight_logs?: InputMaybe<Scalars['String']>;
    is_beacon?: InputMaybe<Scalars['Boolean']>;
    messages: Scalars['String'];
    resources: Scalars['String'];
    session_id: Scalars['ID'];
};
export declare type Query = {
    __typename?: 'Query';
    ignore?: Maybe<Scalars['Any']>;
};
export declare type QueryIgnoreArgs = {
    id: Scalars['ID'];
};
export declare type ReplayEventInput = {
    _sid: Scalars['Float'];
    data: Scalars['Any'];
    timestamp: Scalars['Float'];
    type: Scalars['Int'];
};
export declare type ReplayEventsInput = {
    events: Array<InputMaybe<ReplayEventInput>>;
};
export declare type Session = {
    __typename?: 'Session';
    id: Scalars['ID'];
    organization_id: Scalars['ID'];
    project_id: Scalars['ID'];
    secure_id: Scalars['String'];
};
export declare type StackFrameInput = {
    args?: InputMaybe<Array<InputMaybe<Scalars['Any']>>>;
    columnNumber?: InputMaybe<Scalars['Int']>;
    fileName?: InputMaybe<Scalars['String']>;
    functionName?: InputMaybe<Scalars['String']>;
    isEval?: InputMaybe<Scalars['Boolean']>;
    isNative?: InputMaybe<Scalars['Boolean']>;
    lineNumber?: InputMaybe<Scalars['Int']>;
    source?: InputMaybe<Scalars['String']>;
};
