import LRU from 'lru-cache';
import fs from 'fs';
var CONTEXT_LINE_MAX_SIZE = 1000;
var CONTEXT_LINES_COUNT = 5;
function coalesceSize(inputSize) {
    if (inputSize === undefined) {
        return CONTEXT_CACHE_DEFAULT_SIZE;
    }
    else if (inputSize <= 0) {
        return undefined;
    }
    else {
        return inputSize;
    }
}
var CONTEXT_CACHE_DEFAULT_SIZE = 10;
var ErrorContext = /** @class */ (function () {
    function ErrorContext(options) {
        this._sourceContextCacheSizeMB = coalesceSize(options.sourceContextCacheSizeMB);
        var lruOptions = {
            // `max` is the max count of cache entries - the docs seemed to imply this
            // was a required parameter so it is set arbitrarily high at 1000 files.
            max: 1000,
            maxSize: this._sourceContextCacheSizeMB
                ? this._sourceContextCacheSizeMB * 1000 * 1000
                : undefined,
            length: function (lines, key) {
                return lines.size;
            },
        };
        this._cache = new LRU(lruOptions);
    }
    ErrorContext.prototype._getOrLoadLines = function (filename) {
        var maybeCached = this._cache.get(filename);
        if (maybeCached !== undefined) {
            return maybeCached.lines;
        }
        var size = 0;
        var contents = fs.readFileSync(filename, 'utf8');
        var lineStrs = contents.split('\n');
        var lines = new Map();
        lineStrs.forEach(function (line, idx) {
            var curLine = line.substring(0, CONTEXT_LINE_MAX_SIZE) + '\n';
            lines.set(idx + 1, curLine);
            size += curLine.length;
        });
        this._cache.set(filename, {
            lines: lines,
            size: size,
        });
        return lines;
    };
    ErrorContext.prototype.getStackFrameContext = function (filename, lineNumber) {
        var lines = this._getOrLoadLines(filename);
        var lineContent = lines.get(lineNumber);
        var linesBefore = '';
        for (var i = lineNumber - CONTEXT_LINES_COUNT; i < lineNumber; i++) {
            var nextLine = lines.get(i);
            if (nextLine !== undefined) {
                linesBefore += nextLine;
            }
        }
        var linesAfter = '';
        for (var i = lineNumber + 1; i < lineNumber + CONTEXT_LINES_COUNT + 1; i++) {
            var nextLine = lines.get(i);
            if (nextLine !== undefined) {
                linesAfter += nextLine;
            }
        }
        return {
            lineContent: lineContent,
            linesBefore: linesBefore,
            linesAfter: linesAfter,
        };
    };
    return ErrorContext;
}());
export { ErrorContext };
